@@ -216,10 +216,10 @@ void set_sym(void);	/* Next scan is for a symbol */
 void set_skip(void);	/* Everyting until ';' dropped */
 void set_skipstr(void);	/* Next string must be dropped */
 
-int rcslex(void);
-int rcsparse(void);
+int yylex(void);
+int yyparse(void);
 
-extern FILE *rcsin;
+extern FILE *yyin;
 extern rcsfile_t *rcsfile;
 
 #endif
