@@ -54,7 +54,7 @@ typedef struct
 		stringlist_t *sl;
 		condstring_t *cs;
 		colorlist_t *cl;
-		INTTYPE	val;
+		int	val;
 	} confref;
 } keyword_t;
 
@@ -140,6 +140,7 @@ static keyword_t keywords[] = {
 	{ "merge_arrows",	TYPE_BOOLEAN,	{ &conf.merge_arrows } },
 	{ "merge_cvsnt",	TYPE_BOOLEAN,	{ &conf.merge_cvsnt } },
 	{ "merge_cvsnt_color",	TYPE_COLOR,	{ &conf.merge_cvsnt_color } },
+	{ "merge_on_tag",	TYPE_BOOLEAN,	{ &conf.merge_on_tag } },
 	{ "arrow_width",	TYPE_NUMBER,	{ &conf.arrow_width } },
 	{ "arrow_length",	TYPE_NUMBER,	{ &conf.arrow_length } },
 	{ "tag_color",		TYPE_COLOR,	{ &conf.tag_color } },
@@ -175,23 +176,23 @@ static keyword_t keywords[] = {
 	{ "map_diff_alt",	TYPE_STRING,	{ &conf.map_diff_alt } },
 	{ "map_merge_href",	TYPE_STRING,	{ &conf.map_merge_href } },
 	{ "map_merge_alt",	TYPE_STRING,	{ &conf.map_merge_alt } },
-	{ "jpeg",		TYPE_VALUE,	{ (void *)IMAGE_JPEG } },
-	{ "png",		TYPE_VALUE,	{ (void *)IMAGE_PNG } },
-	{ "gif",		TYPE_VALUE,	{ (void *)IMAGE_GIF } },
-	{ "true",		TYPE_VALUE,	{ (void *)1 } },
-	{ "false",		TYPE_VALUE,	{ (void *)0 } },
-	{ "not",		TYPE_VALUE,	{ (void *)-1 } },
-	{ "left",		TYPE_VALUE,	{ (void *)0 } },
-	{ "center",		TYPE_VALUE,	{ (void *)1 } },
-	{ "right",		TYPE_VALUE,	{ (void *)2 } },
-	{ "tiny",		TYPE_VALUE,	{ (void *)0 } },
-	{ "small",		TYPE_VALUE,	{ (void *)1 } },
-	{ "medium",		TYPE_VALUE,	{ (void *)2 } },
-	{ "large",		TYPE_VALUE,	{ (void *)3 } },
-	{ "giant",		TYPE_VALUE,	{ (void *)4 } },
-	{ "HTML3",		TYPE_VALUE,	{ (void *)1 } },
-	{ "HTML4",		TYPE_VALUE,	{ (void *)2 } },
-	{ "XHTML",		TYPE_VALUE,	{ (void *)3 } },
+	{ "jpeg",		TYPE_VALUE,	{ val: IMAGE_JPEG } },
+	{ "png",		TYPE_VALUE,	{ val: IMAGE_PNG } },
+	{ "gif",		TYPE_VALUE,	{ val: IMAGE_GIF } },
+	{ "true",		TYPE_VALUE,	{ val: 1 } },
+	{ "false",		TYPE_VALUE,	{ val: 0 } },
+	{ "not",		TYPE_VALUE,	{ val: -1 } },
+	{ "left",		TYPE_VALUE,	{ val: 0 } },
+	{ "center",		TYPE_VALUE,	{ val: 1 } },
+	{ "right",		TYPE_VALUE,	{ val: 2 } },
+	{ "tiny",		TYPE_VALUE,	{ val: 0 } },
+	{ "small",		TYPE_VALUE,	{ val: 1 } },
+	{ "medium",		TYPE_VALUE,	{ val: 2 } },
+	{ "large",		TYPE_VALUE,	{ val: 3 } },
+	{ "giant",		TYPE_VALUE,	{ val: 4 } },
+	{ "HTML3",		TYPE_VALUE,	{ val: 1 } },
+	{ "HTML4",		TYPE_VALUE,	{ val: 2 } },
+	{ "XHTML",		TYPE_VALUE,	{ val: 3 } },
 };
 
 #define NKEYWORDS	(sizeof(keywords) / sizeof(keywords[0]))
@@ -383,6 +384,7 @@ void dump_config(void)
 	debug_pstringlist("merge_to", &conf.merge_to);
 	debug_pbool("merge_front", conf.merge_front);
 	debug_pbool("merge_nocase", conf.merge_nocase);
+	debug_pbool("merge_on_tag", conf.merge_on_tag);
 
 	debug_pcolor("msg_color", &conf.msg_color);
 	debug_pfont("msg_font", conf.msg_font.gdfont);
