@@ -30,5 +30,39 @@
 extern int line_number;
 void stack_option(const char *opt);
 void read_config(const char *path);
+color_t *get_colorref(const char *confcolor, int idx);
+
+enum {
+	TYPE_dummy = 256,
+	TYPE_KEYWORD,
+	TYPE_NUMBER,
+	TYPE_VALUE,
+	TYPE_BOOLEAN,
+	TYPE_COLOR,
+	TYPE_FONT,
+	TYPE_STRING,
+	TYPE_CSTRING,
+	TYPE_DOUBLE,
+	TYPE_COLORLIST,
+	TYPE_STRINGLIST,
+	OP_FIRST,
+	OP_CONTAINED,
+	OP_CONTAINEDI,
+	OP_NCONTAINED,
+	OP_NCONTAINEDI,
+	OP_EQ,
+	OP_NE,
+	OP_GE,
+	OP_GT,
+	OP_LE,
+	OP_LT,
+	OP_LAST,
+	KEY_STATE,
+	KEY_AUTHOR,
+	KEY_TAG,
+	KEY_DATE,
+	KEY_REV,
+	KEY_UNKNOWN
+};
 
 #endif
