@@ -24,7 +24,10 @@
 #include <stdarg.h>
 #include <string.h>
 
+#include <gd.h>
+
 #include "utils.h"
+#include "cvsgraph.h"
 #include "readconf.h"
 
 const char *input_file;
